@@ -27,6 +27,8 @@ namespace Ui {
     class Module;
 }
 
+class QLabel;
+
 class Module : public KCModule
 {
     Q_OBJECT
@@ -42,27 +44,34 @@ public:
     /**
      * Destructor.
      */
-    ~Module();
+    ~Module() override;
 
     /**
      * Overloading the KCModule load() function.
      */
-    void load() Q_DECL_OVERRIDE;
+    void load() override;
 
     /**
      * Overloading the KCModule save() function.
      */
-    void save() Q_DECL_OVERRIDE;
+    void save() override;
 
     /**
      * Overloading the KCModule defaults() function.
      */
-    void defaults() Q_DECL_OVERRIDE;
+    void defaults() override;
 
 private:
     void loadSoftware();
     void loadHardware();
 
+    /**
+     * Copies the software and hardware information to clipboard.
+     */
+    void copyToClipboard();
+
+    QVector<QPair<QLabel*, QLabel*> > labelsForClipboard;
+
     /**
      * UI
      */
