@@ -49,7 +49,7 @@
 
 int my_reset_handler(raw1394handle_t handle, unsigned int) {
 	View1394* view1394=(View1394*)raw1394_get_userdata(handle);
-	if (view1394!=0)
+    if (view1394)
 		view1394->rescanBus();
 	return 0;
 }
@@ -118,7 +118,7 @@ bool View1394::readConfigRom(raw1394handle_t handle, nodeid_t nodeid, quadlet_t&
 		}
 		tv.tv_sec=0;
 		tv.tv_usec=10*1000;
-		select(0, 0, 0, 0, &tv);
+        select(0, nullptr, nullptr, nullptr, &tv);
 	}
 	if (firstQuad==0)
 		return false;
@@ -168,7 +168,7 @@ void View1394::rescanBus() {
 	m_view->m_listview->clear();
 
 	raw1394handle_t handle=raw1394_new_handle();
-	if (handle==NULL) {
+    if (handle==nullptr) {
 		m_insideRescanBus=false;
 		return;
 	}
@@ -215,7 +215,7 @@ void View1394::rescanBus() {
 			//minimal config rom
 			if (((firstQuad>>24) & 0xff)==1) {
 				QString guidStr=QString::number(firstQuad, 16);
-				guidStr="0x"+guidStr.rightJustified(6, '0');
+                guidStr="0x"+guidStr.rightJustified(6, QLatin1Char('0'));
 				
 				QStringList romList;
 				romList << nodeStr << guidStr;
@@ -227,13 +227,13 @@ void View1394::rescanBus() {
 				char buf[32];
 				snprintf(buf, 32, "%lX", guid);
 				guidStr=buf;
-				guidStr="0x"+guidStr.rightJustified(16, '0');
-				QString local=((j | 0xffc0) == localNodeId) ? "X" : "";
-				QString irmStr=(cap & 0x80000000) ? "X" : "";
-				QString cmStr=(cap & 0x40000000) ? "X" : "";
-				QString isStr=(cap & 0x20000000) ? "X" : "";
-				QString bmStr=(cap & 0x10000000) ? "X" : "";
-				QString pmStr=(cap & 0x08000000) ? "X" : "";
+                guidStr="0x"+guidStr.rightJustified(16, QLatin1Char('0'));
+                QString local=((j | 0xffc0) == localNodeId) ? QStringLiteral("X") : QString();
+                QString irmStr=(cap & 0x80000000) ? QStringLiteral("X") : QString();
+                QString cmStr=(cap & 0x40000000) ? QStringLiteral("X") : QString();
+                QString isStr=(cap & 0x20000000) ? QStringLiteral("X") : QString();
+                QString bmStr=(cap & 0x10000000) ? QStringLiteral("X") : QString();
+                QString pmStr=(cap & 0x08000000) ? QStringLiteral("X") : QString();
 				QString accStr=QString::number((cap &0x00ff0000)>>16);
 				int speed=(cap & 0x00000007);
 				QString speedStr;
