@@ -29,6 +29,7 @@
 #include <KLocalizedString>
 #include <config-workspace.h>
 #include <KDBusService>
+#include <KWindowSystem>
 
 //Qt
 #include <QCommandLineParser>
@@ -41,7 +42,7 @@ KicApp::KicApp(int &argc, char **argv)
 
     const auto displayName = i18n("Info Center");
     KAboutData aboutData( QStringLiteral("kinfocenter"), displayName,
-        PROJECT_VERSION, displayName, KAboutLicense::GPL,
+        QString::fromLatin1(PROJECT_VERSION), displayName, KAboutLicense::GPL,
         i18n("Copyright 2009-2018 KDE"));
 
     aboutData.addAuthor(i18n("David Hubner"),i18n("Current Maintainer"), QStringLiteral("hubnerd@ntlworld.com"));
@@ -55,16 +56,18 @@ KicApp::KicApp(int &argc, char **argv)
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("hwinfo")));
 
     QCommandLineParser parser;
-    parser.addHelpOption();
-    parser.addVersionOption();
     aboutData.setupCommandLine(&parser);
     parser.process(*this);
     aboutData.processCommandLine(&parser);
 
+    auto *service = new KDBusService(KDBusService::Unique, this);
+
     display = new KInfoCenter();
     display->show();
 
-    (void)new KDBusService(KDBusService::Unique, this);
+    connect(service, &KDBusService::activateRequested, this, [this]() {
+        KWindowSystem::forceActiveWindow(display->winId());
+    });
 }
 
 int main(int argc, char *argv[])
